@@ -2,7 +2,7 @@ use bevy::math::vec2;
 use bevy::prelude::*;
 use bevy_sprite_grid::prelude::*;
 
-fn spawn_tile_map(
+fn spawn_grid(
     mut commands: Commands,
 ) {
     for (z, (alignment, color)) in [
@@ -21,7 +21,7 @@ fn spawn_tile_map(
                 } else {
                     Color::NAVY
                 };
-                sprite_grid[[i, j]] = SpriteCell::color(cell_color);
+                sprite_grid[[i, j]] = Some(SpriteCell::color(cell_color));
             }
         }
         commands.spawn_bundle(SpriteGridBundle {
@@ -37,6 +37,6 @@ fn main() {
     .add_plugins(DefaultPlugins)
     .add_plugin(SpriteGridPlugin)
     .add_startup_system(|mut commands: Commands| { commands.spawn_bundle(OrthographicCameraBundle::new_2d()); })
-    .add_startup_system(spawn_tile_map)
+    .add_startup_system(spawn_grid)
     .run();
 }
\ No newline at end of file
