@@ -3,6 +3,7 @@ pub mod render;
 pub mod picking;
 pub mod sprite_cell;
 pub mod sprite_grid;
+pub mod view;
 
 pub mod prelude {
     pub use crate::bundles::*;
@@ -10,6 +11,7 @@ pub mod prelude {
     pub use crate::sprite_cell::*;
     pub use crate::sprite_grid::*;
     pub use crate::SpriteGridPlugin;
+    pub use crate::view::*;
 }
 
 use bevy::prelude::*;
